@@ -5,13 +5,20 @@
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 47 $"
+__version__ = "$Rev: 52 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
 except:
     version = __version__
 
+import xfree86
+from xfree86 import *
+
+
+import colors
+from colors import *
+
 import copybutton
 from copybutton import *
 
