@@ -6,8 +6,9 @@ def test_logging():
     l = Logging("INFO")
     l.info("test")
     l.level = "WARNING"
-    l.info("test")
     l.level == "INFO"
+    l.level == "CRITICAL"
+    l.level == "ERROR"
 
     try:
         l.level = "WARN"
